pub struct ReservedQuantity {
    pub total_reserved_quantity: Option<i32>,
    pub pending_customer_order_quantity: Option<i32>,
    pub pending_transshipment_quantity: Option<i32>,
    pub fc_processing_quantity: Option<i32>,
}
ReservedQuantity : The quantity of reserved inventory.

Fields

total_reserved_quantity: Option<i32>

The total number of units in Amazon’s fulfillment network that are currently being picked, packed, and shipped; or are sidelined for measurement, sampling, or other internal processes.

pending_customer_order_quantity: Option<i32>

The number of units reserved for customer orders.

pending_transshipment_quantity: Option<i32>

The number of units being transferred from one fulfillment center to another.

fc_processing_quantity: Option<i32>

The number of units that have been sidelined at the fulfillment center for additional processing.

Implementations

The quantity of reserved inventory.